gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnunet] branch master updated: -fix typos


From: gnunet
Subject: [gnunet] branch master updated: -fix typos
Date: Mon, 26 Apr 2021 20:03:02 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository gnunet.

The following commit(s) were added to refs/heads/master by this push:
     new 1f2674fe2 -fix typos
1f2674fe2 is described below

commit 1f2674fe293be7c1a852fbe4a7241fbcb149078f
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Mon Apr 26 20:00:55 2021 +0200

    -fix typos
---
 src/arm/arm.h                                            |  4 ++--
 src/ats/gnunet-service-ats_addresses.h                   |  8 ++++----
 src/ats/gnunet-service-ats_plugins.h                     |  2 +-
 src/cadet/gnunet-service-cadet.h                         |  2 +-
 src/cadet/gnunet-service-cadet_channel.h                 |  2 +-
 src/cadet/gnunet-service-cadet_connection.h              |  2 +-
 src/cadet/gnunet-service-cadet_paths.h                   |  4 ++--
 src/cadet/gnunet-service-cadet_peer.h                    |  2 +-
 src/cadet/gnunet-service-cadet_tunnels.h                 |  4 ++--
 src/fs/fs_api.h                                          |  4 ++--
 src/fs/fs_tree.h                                         |  2 +-
 src/fs/gnunet-service-fs_cadet.h                         |  2 +-
 src/fs/gnunet-service-fs_pr.h                            |  2 +-
 src/include/gnunet_disk_lib.h                            |  2 +-
 src/include/gnunet_messenger_service.h                   |  2 +-
 src/include/gnunet_testing_ng_lib.h                      |  2 +-
 src/messenger/gnunet-service-messenger_handle.h          |  6 +++---
 src/messenger/gnunet-service-messenger_member_session.h  |  2 +-
 src/messenger/gnunet-service-messenger_operation.h       |  2 +-
 src/messenger/gnunet-service-messenger_operation_store.h |  2 +-
 src/messenger/gnunet-service-messenger_room.h            |  4 ++--
 src/messenger/messenger_api_contact_store.h              |  2 +-
 src/messenger/messenger_api_list_tunnels.h               |  2 +-
 src/namecache/namecache.h                                |  4 ++--
 src/nat/nat_stun.h                                       |  2 +-
 src/regex/regex_block_lib.h                              |  2 +-
 src/regex/regex_internal.h                               |  4 ++--
 src/regex/regex_internal_lib.h                           |  2 +-
 src/rps/gnunet-service-rps_custommap.h                   |  4 ++--
 src/rps/gnunet-service-rps_sampler.h                     |  5 ++---
 src/rps/rps-sampler_client.h                             |  4 ++--
 src/rps/rps-sampler_common.h                             |  4 ++--
 src/rps/rps-test_util.h                                  |  2 +-
 src/rps/rps.h                                            |  2 +-
 src/secretsharing/secretsharing.h                        |  2 +-
 src/secretsharing/secretsharing_protocol.h               |  4 ++--
 src/set/gnunet-service-set.h                             |  2 +-
 src/set/gnunet-service-set_union.h                       |  8 ++++----
 src/set/set.h                                            |  6 +++---
 src/seti/seti.h                                          |  2 +-
 src/setu/setu.h                                          |  2 +-
 src/testbed/gnunet-service-testbed.h                     |  4 ++--
 src/testbed/gnunet-service-testbed_barriers.h            |  2 +-
 src/testbed/gnunet-service-testbed_links.c               | 10 +++++-----
 src/testbed/gnunet-service-testbed_links.h               | 12 ++++++------
 src/testbed/testbed_api.h                                |  4 ++--
 src/testbed/testbed_api_hosts.h                          |  2 +-
 src/testbed/testbed_api_operations.h                     |  4 ++--
 src/testbed/testbed_api_peers.h                          |  2 +-
 src/testbed/testbed_api_topology.h                       |  2 +-
 src/transport/communicator.h                             |  2 +-
 src/transport/ieee80211_radiotap.h                       |  2 +-
 src/transport/plugin_transport_wlan.h                    |  2 +-
 src/transport/transport-testing.h                        |  6 +++---
 src/transport/transport-testing2.h                       |  6 +++---
 src/transport/transport.h                                |  8 ++++----
 src/util/benchmark.h                                     |  2 +-
 57 files changed, 98 insertions(+), 99 deletions(-)

diff --git a/src/arm/arm.h b/src/arm/arm.h
index 15f24b3f6..8888e0105 100644
--- a/src/arm/arm.h
+++ b/src/arm/arm.h
@@ -124,13 +124,13 @@ struct GNUNET_ARM_ServiceInfoMessage
   uint32_t status;
 
   /**
-   * Time when the sevice will be restarted, if applicable
+   * Time when the service will be restarted, if applicable
    * to the current status.
    */
   struct GNUNET_TIME_AbsoluteNBO restart_at;
 
   /**
-   * Time when the sevice was first started, if applicable.
+   * Time when the service was first started, if applicable.
    */
   struct GNUNET_TIME_AbsoluteNBO last_started_at;
 };
diff --git a/src/ats/gnunet-service-ats_addresses.h 
b/src/ats/gnunet-service-ats_addresses.h
index a18cce2c7..b39484f59 100644
--- a/src/ats/gnunet-service-ats_addresses.h
+++ b/src/ats/gnunet-service-ats_addresses.h
@@ -57,7 +57,7 @@
  *
  *    ATS specifies a fix set of networks an address can belong to. For each
  *    network an inbound and outbound quota will be specified. The available
- *    networks and addtional helper varaibles are defined in
+ *    networks and additional helper variables are defined in
  *    gnunet_ats_service.h. At the moment 5 networks are defined:
  *      * GNUNET_NT_UNSPECIFIED
  *      * GNUNET_NT_LOOPBACK
@@ -123,7 +123,7 @@
  *      * s_init: init the solver with required information
  *      * s_add: add a new address
  *      * s_update: update ATS values or session for an address
- *      * s_get: get prefered address for a peer
+ *      * s_get: get preferred address for a peer
  *      * s_del: delete an address
  *      * s_pref: change preference value for a peer
  *      * s_done: shutdown solver
@@ -180,7 +180,7 @@
  *    The address client issues a request address message to be notified about
  *    address suggestions for a specific peer. Addresses asks the solver with
  *    s_get. If no address is available, it will not send a response, otherwise
- *    it will respond with the choosen address.
+ *    it will respond with the chosen address.
  *
  *       1.7.5 Address suggestions
  *
@@ -213,7 +213,7 @@
  *     1.9 Changing peer preferences
  *
  *    The bandwidth assigned to a peer can be influenced by setting a 
preference
- *    for a peer. The prefernce will be given to to the solver with s_pref 
which
+ *    for a peer. The preference will be given to to the solver with s_pref 
which
  *    has to take care of the preference value
  */
 
diff --git a/src/ats/gnunet-service-ats_plugins.h 
b/src/ats/gnunet-service-ats_plugins.h
index 4165fe9e2..0bd358917 100644
--- a/src/ats/gnunet-service-ats_plugins.h
+++ b/src/ats/gnunet-service-ats_plugins.h
@@ -34,7 +34,7 @@
  * Initialize address subsystem. The addresses subsystem manages the addresses
  * known and current performance information. It has a solver component
  * responsible for the resource allocation. It tells the solver about changes
- * and receives updates when the solver changes the ressource allocation.
+ * and receives updates when the solver changes the resource allocation.
  *
  * @param cfg configuration to use
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error (failed to load
diff --git a/src/cadet/gnunet-service-cadet.h b/src/cadet/gnunet-service-cadet.h
index 6da0950f1..3d61b9973 100644
--- a/src/cadet/gnunet-service-cadet.h
+++ b/src/cadet/gnunet-service-cadet.h
@@ -181,7 +181,7 @@ struct CadetConnection;
 struct CadetRoute;
 
 /**
- * Logical end-to-end conenction between clients.  There can be
+ * Logical end-to-end connection between clients.  There can be
  * any number of channels between clients.
  */
 struct CadetChannel;
diff --git a/src/cadet/gnunet-service-cadet_channel.h 
b/src/cadet/gnunet-service-cadet_channel.h
index 7a072f128..6d691cafc 100644
--- a/src/cadet/gnunet-service-cadet_channel.h
+++ b/src/cadet/gnunet-service-cadet_channel.h
@@ -34,7 +34,7 @@
 
 /**
  * A channel is a bidirectional connection between two CADET
- * clients.  Communiation can be reliable, unreliable, in-order
+ * clients.  Communication can be reliable, unreliable, in-order
  * or out-of-order.  One client is the "local" client, this
  * one initiated the connection.   The other client is the
  * "incoming" client, this one listened on a port to accept
diff --git a/src/cadet/gnunet-service-cadet_connection.h 
b/src/cadet/gnunet-service-cadet_connection.h
index ed0e909fb..d646b3dc2 100644
--- a/src/cadet/gnunet-service-cadet_connection.h
+++ b/src/cadet/gnunet-service-cadet_connection.h
@@ -37,7 +37,7 @@
 
 
 /**
- * Function called to notify tunnel about change in our readyness.
+ * Function called to notify tunnel about change in our readiness.
  *
  * @param cls closure
  * @param is_ready #GNUNET_YES if the connection is now ready for transmission,
diff --git a/src/cadet/gnunet-service-cadet_paths.h 
b/src/cadet/gnunet-service-cadet_paths.h
index 125ea669a..3961dd721 100644
--- a/src/cadet/gnunet-service-cadet_paths.h
+++ b/src/cadet/gnunet-service-cadet_paths.h
@@ -37,7 +37,7 @@
  * if applicable.
  *
  * @param get_path path of the get request
- * @param get_path_length lenght of @a get_path
+ * @param get_path_length length of @a get_path
  * @param put_path path of the put request
  * @param put_path_length length of the @a put_path
  */
@@ -130,7 +130,7 @@ GCPP_find_peer (struct CadetPeerPath *path,
 /**
  * Return how much we like keeping the path.  This is an aggregate
  * score based on various factors, including the age of the path
- * (older == better), and the value of this path to all of its ajacent
+ * (older == better), and the value of this path to all of its adjacent
  * peers.  For example, long paths that end at a peer that we have no
  * shorter way to reach are very desirable, while long paths that end
  * at a peer for which we have a shorter way as well are much less
diff --git a/src/cadet/gnunet-service-cadet_peer.h 
b/src/cadet/gnunet-service-cadet_peer.h
index 5782b8bff..7a39615ff 100644
--- a/src/cadet/gnunet-service-cadet_peer.h
+++ b/src/cadet/gnunet-service-cadet_peer.h
@@ -43,7 +43,7 @@ GCP_2s (const struct CadetPeer *peer);
 
 
 /**
- * Retrieve the CadetPeer stucture associated with the
+ * Retrieve the CadetPeer structure associated with the
  * peer. Optionally create one and insert it in the appropriate
  * structures if the peer is not known yet.
  *
diff --git a/src/cadet/gnunet-service-cadet_tunnels.h 
b/src/cadet/gnunet-service-cadet_tunnels.h
index 075cd03f8..aea131542 100644
--- a/src/cadet/gnunet-service-cadet_tunnels.h
+++ b/src/cadet/gnunet-service-cadet_tunnels.h
@@ -101,7 +101,7 @@ GCT_2s (const struct CadetTunnel *t);
 
 
 /**
- * Create a tunnel to @a destionation.  Must only be called
+ * Create a tunnel to @a destination.  Must only be called
  * from within #GCP_get_tunnel().
  *
  * @param destination where to create the tunnel to
@@ -124,7 +124,7 @@ GCT_destroy_tunnel_now (struct CadetTunnel *t);
  * Add a @a connection to the @a tunnel.
  *
  * @param t a tunnel
- * @param cid connection identifer to use for the connection
+ * @param cid connection identifier to use for the connection
  * @param path path to use for the connection
  * @return #GNUNET_OK on success,
  *         #GNUNET_SYSERR on failure (duplicate connection)
diff --git a/src/fs/fs_api.h b/src/fs/fs_api.h
index 0228e37ce..050d5f46c 100644
--- a/src/fs/fs_api.h
+++ b/src/fs/fs_api.h
@@ -35,7 +35,7 @@
 #include "fs.h"
 
 /**
- * Pick a multiple of 2 here to achive 8-byte alignment!  We also
+ * Pick a multiple of 2 here to achieve 8-byte alignment!  We also
  * probably want DBlocks to have (roughly) the same size as IBlocks.
  * With SHA-512, the optimal value is 32768 byte / 128 byte = 256 (128
  * byte = 2 * 512 bits).  DO NOT CHANGE!
@@ -1141,7 +1141,7 @@ struct GNUNET_FS_Handle
 
   /**
    * Average time we take for a single request to be satisfied.
-   * FIXME: not yet calcualted properly...
+   * FIXME: not yet calculated properly...
    */
   struct GNUNET_TIME_Relative avg_block_latency;
 
diff --git a/src/fs/fs_tree.h b/src/fs/fs_tree.h
index 12b5b5d07..1fb681d27 100644
--- a/src/fs/fs_tree.h
+++ b/src/fs/fs_tree.h
@@ -172,7 +172,7 @@ GNUNET_FS_tree_encoder_get_uri (struct 
GNUNET_FS_TreeEncoder *te);
  * about possible errors.
  *
  * @param te the tree encoder to clean up
- * @param emsg set to an error message (if an error occured
+ * @param emsg set to an error message (if an error occurred
  *        within the tree encoder; if this function is called
  *        prior to completion and prior to an internal error,
  *        both "*emsg" will be set to NULL).
diff --git a/src/fs/gnunet-service-fs_cadet.h b/src/fs/gnunet-service-fs_cadet.h
index b8c255047..c02021a0d 100644
--- a/src/fs/gnunet-service-fs_cadet.h
+++ b/src/fs/gnunet-service-fs_cadet.h
@@ -82,7 +82,7 @@ GSF_cadet_release_clients (void *cls,
 
 /**
  * Cancel an active request; must not be called after 'proc'
- * was calld.
+ * was called.
  *
  * @param sr request to cancel
  */
diff --git a/src/fs/gnunet-service-fs_pr.h b/src/fs/gnunet-service-fs_pr.h
index e060e734e..58fdd334e 100644
--- a/src/fs/gnunet-service-fs_pr.h
+++ b/src/fs/gnunet-service-fs_pr.h
@@ -207,7 +207,7 @@ typedef void
  * @param bf_size number of bytes in bf_data
  * @param mingle mingle value for bf
  * @param anonymity_level desired anonymity level
- * @param priority maximum outgoing cummulative request priority to use
+ * @param priority maximum outgoing cumulative request priority to use
  * @param ttl current time-to-live for the request
  * @param sender_pid peer ID to use for the sender when forwarding, 0 for none;
  *                   reference counter is taken over by this function
diff --git a/src/include/gnunet_disk_lib.h b/src/include/gnunet_disk_lib.h
index 0fbdd7ab3..3805039fc 100644
--- a/src/include/gnunet_disk_lib.h
+++ b/src/include/gnunet_disk_lib.h
@@ -503,7 +503,7 @@ GNUNET_DISK_pipe_handle (const struct 
GNUNET_DISK_PipeHandle *p,
 
 
 /**
- * Update POSIX permissions mask of a file on disk.  If both argumets
+ * Update POSIX permissions mask of a file on disk.  If both arguments
  * are #GNUNET_NO, the file is made world-read-write-executable (777).
  * Does nothing on W32.
  *
diff --git a/src/include/gnunet_messenger_service.h 
b/src/include/gnunet_messenger_service.h
index 99d4cf267..0576e239f 100644
--- a/src/include/gnunet_messenger_service.h
+++ b/src/include/gnunet_messenger_service.h
@@ -172,7 +172,7 @@ GNUNET_MESSENGER_name_of_kind (enum 
GNUNET_MESSENGER_MessageKind kind);
 
 /**
  * The header of a #GNUNET_MESSENGER_Message.
- * This allows authentification of the sender, temporal ordering and finding 
potentially missed messages.
+ * This allows authentication of the sender, temporal ordering and finding 
potentially missed messages.
  *
  * Message-header-size: 40+ bytes
  */
diff --git a/src/include/gnunet_testing_ng_lib.h 
b/src/include/gnunet_testing_ng_lib.h
index 001d92aad..55c8a7246 100644
--- a/src/include/gnunet_testing_ng_lib.h
+++ b/src/include/gnunet_testing_ng_lib.h
@@ -161,7 +161,7 @@ struct GNUNET_TESTING_Command
 
   /**
    * How often did we try to execute this command? (In case it is a request
-   * that is repated.)  Note that a command must have some build-in retry
+   * that is repated.)  Note that a command must have some built-in retry
    * mechanism for this value to be useful.
    */
   unsigned int num_tries;
diff --git a/src/messenger/gnunet-service-messenger_handle.h 
b/src/messenger/gnunet-service-messenger_handle.h
index 70b2cac6d..d8ff3aaa8 100644
--- a/src/messenger/gnunet-service-messenger_handle.h
+++ b/src/messenger/gnunet-service-messenger_handle.h
@@ -112,7 +112,7 @@ change_handle_member_id (struct GNUNET_MESSENGER_SrvHandle 
*handle, const struct
  * Sets the EGO used by a given <i>handle</i>.
  *
  * @param[in/out] handle Handle
- * @param[in] ego EGO keypair
+ * @param[in] ego EGO key pair
  */
 void
 set_handle_ego (struct GNUNET_MESSENGER_SrvHandle *handle, const struct 
GNUNET_MESSENGER_Ego *ego);
@@ -121,7 +121,7 @@ set_handle_ego (struct GNUNET_MESSENGER_SrvHandle *handle, 
const struct GNUNET_M
  * Returns the EGO used by a given <i>handle</i>.
  *
  * @param[in] handle Handle
- * @return EGO keypair
+ * @return EGO key pair
  */
 const struct GNUNET_MESSENGER_Ego*
 get_handle_ego (const struct GNUNET_MESSENGER_SrvHandle *handle);
@@ -136,7 +136,7 @@ void
 setup_handle_name (struct GNUNET_MESSENGER_SrvHandle *handle, const char 
*name);
 
 /**
- * Tries to change the keypair of an EGO of a <i>handle</i> under the same 
name and informs all rooms
+ * Tries to change the key pair of an EGO of a <i>handle</i> under the same 
name and informs all rooms
  * about the change automatically.
  *
  * @param[in/out] handle Handle
diff --git a/src/messenger/gnunet-service-messenger_member_session.h 
b/src/messenger/gnunet-service-messenger_member_session.h
index fa9c6b829..bf4d10f67 100644
--- a/src/messenger/gnunet-service-messenger_member_session.h
+++ b/src/messenger/gnunet-service-messenger_member_session.h
@@ -188,7 +188,7 @@ const struct GNUNET_HashCode*
 get_member_session_context (const struct GNUNET_MESSENGER_MemberSession* 
session);
 
 /**
- * Retruns the contact which is connected to a given member <i>session</i>.
+ * Returns the contact which is connected to a given member <i>session</i>.
  *
  * @param[in] session Member session
  * @return Contact
diff --git a/src/messenger/gnunet-service-messenger_operation.h 
b/src/messenger/gnunet-service-messenger_operation.h
index 7757b8e88..f1e06f4a7 100644
--- a/src/messenger/gnunet-service-messenger_operation.h
+++ b/src/messenger/gnunet-service-messenger_operation.h
@@ -102,7 +102,7 @@ save_operation (const struct GNUNET_MESSENGER_Operation 
*op, const char *path);
 /**
  * Starts an inactive operation with a given <i>delay</i> in a
  * specific operation <i>store</i>. The method will replace the
- * operations type to process it correctly. An opeation can't be
+ * operations type to process it correctly. An operation can't be
  * started twice, it has to be stopped or fully processed first.
  *
  * @param[in/out] op Operation
diff --git a/src/messenger/gnunet-service-messenger_operation_store.h 
b/src/messenger/gnunet-service-messenger_operation_store.h
index 2fd604340..4c613437c 100644
--- a/src/messenger/gnunet-service-messenger_operation_store.h
+++ b/src/messenger/gnunet-service-messenger_operation_store.h
@@ -79,7 +79,7 @@ save_operation_store (const struct 
GNUNET_MESSENGER_OperationStore *store,
                       const char *directory);
 
 /**
- * Retruns the type of the active operation under a given <i>hash</i> in
+ * Returns the type of the active operation under a given <i>hash</i> in
  * a specific operation <i>store</i>. If there is no active operation under
  * the given <i>hash</i>, #GNUNET_MESSENGER_OP_UNKNOWN gets returned instead.
  *
diff --git a/src/messenger/gnunet-service-messenger_room.h 
b/src/messenger/gnunet-service-messenger_room.h
index b6a0f1064..31ec877af 100644
--- a/src/messenger/gnunet-service-messenger_room.h
+++ b/src/messenger/gnunet-service-messenger_room.h
@@ -132,7 +132,7 @@ get_room_operation_store (struct GNUNET_MESSENGER_SrvRoom 
*room);
  *
  * Calling this method should result in joining a room and sending a peer 
message as well for this peer.
  *
- * If the function returns #GNUNET_YES the port for this room is guranteed to 
be open for incoming connections.
+ * If the function returns #GNUNET_YES the port for this room is guaranteed to 
be open for incoming connections.
  *
  * @param[in/out] room Room
  * @param[in/out] handle Handle
@@ -160,7 +160,7 @@ enter_room_at (struct GNUNET_MESSENGER_SrvRoom *room, 
struct GNUNET_MESSENGER_Sr
  * timestamp of the message, the sender id and the previous messages hash 
automatically before packing. The message
  * will be signed by the handles EGO.
  *
- * If the optional <i>hash</i> parameter is a valid pointer, its value will be 
overriden by the signed messages hash.
+ * If the optional <i>hash</i> parameter is a valid pointer, its value will be 
overridden by the signed messages hash.
  *
  * If <i>mode</i> is set to #GNUNET_MESSENGER_PACK_MODE_ENVELOPE, the function 
returns a valid envelope to send
  * through a message queue, otherwise NULL.
diff --git a/src/messenger/messenger_api_contact_store.h 
b/src/messenger/messenger_api_contact_store.h
index 966f6d962..f2dad9f84 100644
--- a/src/messenger/messenger_api_contact_store.h
+++ b/src/messenger/messenger_api_contact_store.h
@@ -79,7 +79,7 @@ get_store_contact_raw (struct GNUNET_MESSENGER_ContactStore 
*store, const struct
  * In case there is no contact stored which uses the given key or context,
  * a new contact will be created automatically.
  *
- * The function returns NULL if an error occures during allocation
+ * The function returns NULL if an error occurs during allocation
  * or validation of the contacts key.
  *
  * @param[in/out] store Contact store
diff --git a/src/messenger/messenger_api_list_tunnels.h 
b/src/messenger/messenger_api_list_tunnels.h
index bd0a42e41..c952da3c2 100644
--- a/src/messenger/messenger_api_list_tunnels.h
+++ b/src/messenger/messenger_api_list_tunnels.h
@@ -75,7 +75,7 @@ add_to_list_tunnels (struct GNUNET_MESSENGER_ListTunnels 
*tunnels, const struct
  *
  * If no matching element is found, NULL gets returned.
  *
- * If <i>index</i> is not NULL, <i>index</i> will be overriden with the 
numeric index of
+ * If <i>index</i> is not NULL, <i>index</i> will be overridden with the 
numeric index of
  * the found element in the list. If no matching element is found, 
<i>index</i> will
  * contain the total amount of elements in the list.
  *
diff --git a/src/namecache/namecache.h b/src/namecache/namecache.h
index 43c8cf85f..4c809b4d1 100644
--- a/src/namecache/namecache.h
+++ b/src/namecache/namecache.h
@@ -94,7 +94,7 @@ struct LookupBlockResponseMessage
    */
   struct GNUNET_IDENTITY_PublicKey derived_key;
 
-  /* follwed by encrypted block data */
+  /* followed by encrypted block data */
 };
 
 
@@ -123,7 +123,7 @@ struct BlockCacheMessage
    */
   struct GNUNET_IDENTITY_PublicKey derived_key;
 
-  /* follwed by encrypted block data */
+  /* followed by encrypted block data */
 };
 
 
diff --git a/src/nat/nat_stun.h b/src/nat/nat_stun.h
index 86b4bd0cb..a31e0f8d6 100644
--- a/src/nat/nat_stun.h
+++ b/src/nat/nat_stun.h
@@ -23,7 +23,7 @@
  * @file nat/nat_stun.h
  * @brief Testcase for STUN library
  * @author Bruno Souza Cabral
- * @autor Mark Spencer (Original code borrowed from Asterisk)
+ * @author Mark Spencer (Original code borrowed from Asterisk)
  * @author Christian Grothoff
  */
 
diff --git a/src/regex/regex_block_lib.h b/src/regex/regex_block_lib.h
index 3368e3456..11029b9af 100644
--- a/src/regex/regex_block_lib.h
+++ b/src/regex/regex_block_lib.h
@@ -58,7 +58,7 @@ struct REGEX_BLOCK_Edge
   const char *label;
 
   /**
-   * Destionation of the edge.
+   * Destination of the edge.
    */
   struct GNUNET_HashCode destination;
 };
diff --git a/src/regex/regex_internal.h b/src/regex/regex_internal.h
index 17b038f21..8f29cff33 100644
--- a/src/regex/regex_internal.h
+++ b/src/regex/regex_internal.h
@@ -203,7 +203,7 @@ struct REGEX_INTERNAL_State
   struct GNUNET_HashCode hash;
 
   /**
-   * Linear state ID accquired by depth-first-search. This ID should be used 
for
+   * Linear state ID acquired by depth-first-search. This ID should be used for
    * storing information about the state in an array, because the 'id' of the
    * state is not guaranteed to be linear. The 'dfs_id' is guaranteed to be > 0
    * and < 'state_count'.
@@ -329,7 +329,7 @@ REGEX_INTERNAL_construct_nfa (const char *regex, const 
size_t len);
 
 
 /**
- * Function that get's passed to automaton traversal and is called before each
+ * Function that gets passed to automaton traversal and is called before each
  * next traversal from state 's' using transition 't' to check if traversal
  * should proceed. Return GNUNET_NO to stop traversal or GNUNET_YES to 
continue.
  *
diff --git a/src/regex/regex_internal_lib.h b/src/regex/regex_internal_lib.h
index cd955e68b..94fac19f9 100644
--- a/src/regex/regex_internal_lib.h
+++ b/src/regex/regex_internal_lib.h
@@ -60,7 +60,7 @@ struct REGEX_INTERNAL_Automaton;
  * @param len length of the regular expression.
  * @param max_path_len limit the path compression length to the
  *        given value. If set to 1, no path compression is applied. Set to 0 
for
- *        maximal possible path compression (generally not desireable).
+ *        maximal possible path compression (generally not desirable).
  * @return DFA, needs to be freed using #REGEX_INTERNAL_automaton_destroy().
  */
 struct REGEX_INTERNAL_Automaton *
diff --git a/src/rps/gnunet-service-rps_custommap.h 
b/src/rps/gnunet-service-rps_custommap.h
index 15591b67a..e7f669c63 100644
--- a/src/rps/gnunet-service-rps_custommap.h
+++ b/src/rps/gnunet-service-rps_custommap.h
@@ -44,10 +44,10 @@
  *
  * This list is expected to
  * - be altered in small steps frequently
- * - be cleared regularily
+ * - be cleared regularly
  * - often being queried whether a peer is contained
  * - alter indices of peers
- * - contain continous indices 0 <= i < len
+ * - contain continuous indices 0 <= i < len
  * - not contain duplicate peers
  */
 struct CustomPeerMap;
diff --git a/src/rps/gnunet-service-rps_sampler.h 
b/src/rps/gnunet-service-rps_sampler.h
index f3a8c9763..410823bea 100644
--- a/src/rps/gnunet-service-rps_sampler.h
+++ b/src/rps/gnunet-service-rps_sampler.h
@@ -125,7 +125,7 @@ RPS_sampler_get_n_rand_peers (struct RPS_Sampler *sampler,
                               void *cls);
 
 /**
- * Cancle a request issued through #RPS_sampler_n_rand_peers_ready_cb.
+ * Cancel a request issued through #RPS_sampler_n_rand_peers_ready_cb.
  *
  * @param req_handle the handle to the request
  */
@@ -136,9 +136,8 @@ RPS_sampler_request_cancel (struct RPS_SamplerRequestHandle 
*req_handle);
 /**
  * Counts how many Samplers currently hold a given PeerID.
  *
- * @param sampler the sampler to cound ids in.
+ * @param sampler the sampler to count ids in.
  * @param id the PeerID to count.
- *
  * @return the number of occurrences of id.
  */
 uint32_t
diff --git a/src/rps/rps-sampler_client.h b/src/rps/rps-sampler_client.h
index e6b808650..7a674371d 100644
--- a/src/rps/rps-sampler_client.h
+++ b/src/rps/rps-sampler_client.h
@@ -123,7 +123,7 @@ RPS_sampler_get_n_rand_peers (struct RPS_Sampler *sampler,
 
 
 /**
- * Cancle a request issued through #RPS_sampler_n_rand_peers_ready_cb.
+ * Cancel a request issued through #RPS_sampler_n_rand_peers_ready_cb.
  *
  * @param req_handle the handle to the request
  */
@@ -134,7 +134,7 @@ RPS_sampler_request_cancel (struct RPS_SamplerRequestHandle 
*req_handle);
 /**
  * Counts how many Samplers currently hold a given PeerID.
  *
- * @param sampler the sampler to cound ids in.
+ * @param sampler the sampler to count ids in.
  * @param id the PeerID to count.
  *
  * @return the number of occurrences of id.
diff --git a/src/rps/rps-sampler_common.h b/src/rps/rps-sampler_common.h
index 72202dc93..c60d37217 100644
--- a/src/rps/rps-sampler_common.h
+++ b/src/rps/rps-sampler_common.h
@@ -363,7 +363,7 @@ RPS_sampler_count_id (struct RPS_Sampler *sampler,
 
 
 /**
- * Cancle a request issued through #RPS_sampler_n_rand_peers_ready_cb.
+ * Cancel a request issued through #RPS_sampler_n_rand_peers_ready_cb.
  *
  * @param req_handle the handle to the request
  */
@@ -372,7 +372,7 @@ RPS_sampler_request_cancel (struct RPS_SamplerRequestHandle 
*req_handle);
 
 
 /**
- * Cancle a request issued through #RPS_sampler_n_rand_peers_ready_cb.
+ * Cancel a request issued through #RPS_sampler_n_rand_peers_ready_cb.
  *
  * @param req_handle the handle to the request
  */
diff --git a/src/rps/rps-test_util.h b/src/rps/rps-test_util.h
index 72aa78803..9ff13bdcf 100644
--- a/src/rps/rps-test_util.h
+++ b/src/rps/rps-test_util.h
@@ -20,7 +20,7 @@
 
 /**
  * @file rps/rps-test_util.h
- * @brief Some utils faciliating the view into the internals for the sampler
+ * @brief Some utils facilitating the view into the internals for the sampler
  *        needed for evaluation
  * @author Julius Bünger
  */
diff --git a/src/rps/rps.h b/src/rps/rps.h
index 9d42a6104..202f881c9 100644
--- a/src/rps/rps.h
+++ b/src/rps/rps.h
@@ -98,7 +98,7 @@ struct GNUNET_RPS_CS_ActMaliciousMessage
   /**
    * Type of malicious behaviour.
    *
-   * 0 No malicious bahaviour at all
+   * 0 No malicious behaviour at all
    * 1 Try to maximise representation
    * 2 Try to partition the network
    */
diff --git a/src/secretsharing/secretsharing.h 
b/src/secretsharing/secretsharing.h
index af6263c46..6e104ebfa 100644
--- a/src/secretsharing/secretsharing.h
+++ b/src/secretsharing/secretsharing.h
@@ -67,7 +67,7 @@ struct GNUNET_SECRETSHARING_CreateMessage
   struct GNUNET_TIME_AbsoluteNBO deadline;
 
   /**
-   * Mininum number of cooperating peers to decrypt a
+   * Minimum number of cooperating peers to decrypt a
    * value.
    */
   uint16_t threshold GNUNET_PACKED;
diff --git a/src/secretsharing/secretsharing_protocol.h 
b/src/secretsharing/secretsharing_protocol.h
index d43d1cee5..d4aaecb6c 100644
--- a/src/secretsharing/secretsharing_protocol.h
+++ b/src/secretsharing/secretsharing_protocol.h
@@ -122,7 +122,7 @@ struct GNUNET_SECRETSHARING_DecryptData
    */
   struct GNUNET_SECRETSHARING_FieldElement nizk_commit2;
   /**
-   * Reponse to the challenge computed from the protocol transcript.
+   * Response to the challenge computed from the protocol transcript.
    * r = \beta + challenge \cdot share_i
    */
   struct GNUNET_SECRETSHARING_FieldElement nizk_response;
@@ -133,7 +133,7 @@ struct GNUNET_SECRETSHARING_FairEncryption
 {
   struct GNUNET_CRYPTO_PaillierCiphertext c;
   /**
-   * h = g^x, where x is the fairly encrypte secret.
+   * h = g^x, where x is the fairly encrypted secret.
    */
   char h[GNUNET_SECRETSHARING_ELGAMAL_BITS / 8];
   char t1[GNUNET_SECRETSHARING_ELGAMAL_BITS / 8];
diff --git a/src/set/gnunet-service-set.h b/src/set/gnunet-service-set.h
index e118828be..abdec7f08 100644
--- a/src/set/gnunet-service-set.h
+++ b/src/set/gnunet-service-set.h
@@ -135,7 +135,7 @@ typedef struct OperationState *
                    const struct GNUNET_MessageHeader *opaque_context);
 
 /**
- * Signature of functions that implement operation cancelation.
+ * Signature of functions that implement operation cancellation.
  * This includes notifying the client about the operation's final
  * state.
  *
diff --git a/src/set/gnunet-service-set_union.h 
b/src/set/gnunet-service-set_union.h
index 2c0262f07..68301c96b 100644
--- a/src/set/gnunet-service-set_union.h
+++ b/src/set/gnunet-service-set_union.h
@@ -154,7 +154,7 @@ handle_union_p2p_inquiry (void *cls,
 /**
  * Handle a request for full set transmission.
  *
- * @parem cls closure, a set union operation
+ * @param cls closure, a set union operation
  * @param mh the demand message
  */
 void
@@ -165,7 +165,7 @@ handle_union_p2p_request_full (void *cls,
 /**
  * Handle a "full done" message.
  *
- * @parem cls closure, a set union operation
+ * @param cls closure, a set union operation
  * @param mh the demand message
  */
 void
@@ -177,7 +177,7 @@ handle_union_p2p_full_done (void *cls,
  * Check a demand by the other peer for elements based on a list
  * of `struct GNUNET_HashCode`s.
  *
- * @parem cls closure, a set union operation
+ * @param cls closure, a set union operation
  * @param mh the demand message
  * @return #GNUNET_OK if @a mh is well-formed
  */
@@ -190,7 +190,7 @@ check_union_p2p_demand (void *cls,
  * Handle a demand by the other peer for elements based on a list
  * of `struct GNUNET_HashCode`s.
  *
- * @parem cls closure, a set union operation
+ * @param cls closure, a set union operation
  * @param mh the demand message
  */
 void
diff --git a/src/set/set.h b/src/set/set.h
index 3fdfad5da..e9d10ea22 100644
--- a/src/set/set.h
+++ b/src/set/set.h
@@ -265,7 +265,7 @@ struct GNUNET_SET_ResultMessage
   uint16_t result_status GNUNET_PACKED;
 
   /**
-   * Type of the element attachted to the message, if any.
+   * Type of the element attached to the message, if any.
    */
   uint16_t element_type GNUNET_PACKED;
 
@@ -329,13 +329,13 @@ struct GNUNET_SET_IterResponseMessage
   struct GNUNET_MessageHeader header;
 
   /**
-   * To which set iteration does this reponse belong to?  First
+   * To which set iteration does this response belong to?  First
    * iteration (per client) has counter zero. Wraps around.
    */
   uint16_t iteration_id GNUNET_PACKED;
 
   /**
-   * Type of the element attachted to the message,
+   * Type of the element attached to the message,
    * if any.
    */
   uint16_t element_type GNUNET_PACKED;
diff --git a/src/seti/seti.h b/src/seti/seti.h
index aa7014034..e780b1061 100644
--- a/src/seti/seti.h
+++ b/src/seti/seti.h
@@ -212,7 +212,7 @@ struct GNUNET_SETI_ResultMessage
   uint16_t result_status GNUNET_PACKED;
 
   /**
-   * Type of the element attachted to the message, if any.
+   * Type of the element attached to the message, if any.
    */
   uint16_t element_type GNUNET_PACKED;
 
diff --git a/src/setu/setu.h b/src/setu/setu.h
index f806c8eb1..7c2a98a02 100644
--- a/src/setu/setu.h
+++ b/src/setu/setu.h
@@ -261,7 +261,7 @@ struct GNUNET_SETU_ResultMessage
   uint16_t result_status GNUNET_PACKED;
 
   /**
-   * Type of the element attachted to the message, if any.
+   * Type of the element attached to the message, if any.
    */
   uint16_t element_type GNUNET_PACKED;
 
diff --git a/src/testbed/gnunet-service-testbed.h 
b/src/testbed/gnunet-service-testbed.h
index ae477ccb4..1c6aadb59 100644
--- a/src/testbed/gnunet-service-testbed.h
+++ b/src/testbed/gnunet-service-testbed.h
@@ -488,7 +488,7 @@ extern char *GST_stats_dir;
  * @param ptr the array pointer to grow
  * @param size the size of array
  * @param accommodate_size the size which the array has to accommdate; after
- *          this call the array will be big enough to accommdate sizes upto
+ *          this call the array will be big enough to accommdate sizes up to
  *          accommodate_size
  */
 #define GST_array_grow_large_enough(ptr, size, accommodate_size) \
@@ -772,7 +772,7 @@ check_peer_reconfigure (void *cls,
 
 /**
  * Handler for #GNUNET_MESSAGE_TYPDE_TESTBED_RECONFIGURE_PEER type messages.
- * Should stop the peer asyncronously, destroy it and create it again with the
+ * Should stop the peer asynchronously, destroy it and create it again with the
  * new configuration.
  *
  * @param cls identification of the client
diff --git a/src/testbed/gnunet-service-testbed_barriers.h 
b/src/testbed/gnunet-service-testbed_barriers.h
index f58e10609..aa2718777 100644
--- a/src/testbed/gnunet-service-testbed_barriers.h
+++ b/src/testbed/gnunet-service-testbed_barriers.h
@@ -28,7 +28,7 @@
 #define GNUNET_SERVER_TESTBED_BARRIERS_H_
 
 /**
- * Function to initialise barrriers component
+ * Function to initialise barriers component
  *
  * @param cfg the configuration to use for initialisation
  */
diff --git a/src/testbed/testbed_api.h b/src/testbed/testbed_api.h
index 17cd38df3..f6808a851 100644
--- a/src/testbed/testbed_api.h
+++ b/src/testbed/testbed_api.h
@@ -156,7 +156,7 @@ struct OperationContext
   void *data;
 
   /**
-   * The id of the opearation
+   * The id of the operation
    */
   uint64_t id;
 
@@ -282,7 +282,7 @@ struct GNUNET_TESTBED_Barrier
   struct GNUNET_HashCode key;
 
   /**
-   * The controller handle given while initiliasing this barrier
+   * The controller handle given while initalising this barrier
    */
   struct GNUNET_TESTBED_Controller *c;
 
diff --git a/src/testbed/testbed_api_hosts.h b/src/testbed/testbed_api_hosts.h
index 9b19eb8ec..291cab859 100644
--- a/src/testbed/testbed_api_hosts.h
+++ b/src/testbed/testbed_api_hosts.h
@@ -48,7 +48,7 @@ struct GNUNET_TESTBED_HostRegistrationHandle
   struct GNUNET_TESTBED_Controller *c;
 
   /**
-   * The Registartion completion callback
+   * The Registration completion callback
    */
   GNUNET_TESTBED_HostRegistrationCompletion cc;
 
diff --git a/src/testbed/testbed_api_operations.h 
b/src/testbed/testbed_api_operations.h
index 2ecbc7b66..d9de5c011 100644
--- a/src/testbed/testbed_api_operations.h
+++ b/src/testbed/testbed_api_operations.h
@@ -163,7 +163,7 @@ typedef void (*OperationStart) (void *cls);
  * "GNUNET_TESTBED_operation_cancel" (before the operation generated
  * an event) or AFTER the operation generated an event due to a call
  * to "GNUNET_TESTBED_operation_done".  Thus it is not guaranteed that
- * a callback to the 'OperationStart' preceeds the call to
+ * a callback to the 'OperationStart' precedes the call to
  * 'OperationRelease'.  Implementations of this function are expected
  * to clean up whatever state is in 'cls' and release all resources
  * associated with the operation.
@@ -210,7 +210,7 @@ GNUNET_TESTBED_operation_inactivate_ (struct 
GNUNET_TESTBED_Operation *op);
 
 
 /**
- * Marks and inactive operation as active.  This fuction should be called to
+ * Marks and inactive operation as active.  This function should be called to
  * ensure that the oprelease callback will not be called until it is either
  * marked as inactive or released.
  *
diff --git a/src/testbed/testbed_api_peers.h b/src/testbed/testbed_api_peers.h
index 9ca104081..db8ec9881 100644
--- a/src/testbed/testbed_api_peers.h
+++ b/src/testbed/testbed_api_peers.h
@@ -247,7 +247,7 @@ struct OverlayConnectData
 
   /**
    * OperationContext for forwarded operations generated when peer1's 
controller doesn't have the
-   * configuration of peer2's controller for linking laterally to attemp an
+   * configuration of peer2's controller for linking laterally to attempt an
    * overlay connection between peer 1 and peer 2.
    */
   struct OperationContext *sub_opc;
diff --git a/src/testbed/testbed_api_topology.h 
b/src/testbed/testbed_api_topology.h
index c303c1412..564fa421f 100644
--- a/src/testbed/testbed_api_topology.h
+++ b/src/testbed/testbed_api_topology.h
@@ -29,7 +29,7 @@
 
 /**
  * Returns the number of links that are required to generate a 2d torus for the
- * given number of peers. Also returns the arrangment (number of rows and the
+ * given number of peers. Also returns the arrangement (number of rows and the
  * length of each row)
  *
  * @param num_peers number of peers
diff --git a/src/transport/communicator.h b/src/transport/communicator.h
index ab7a25de6..5ef43597d 100644
--- a/src/transport/communicator.h
+++ b/src/transport/communicator.h
@@ -116,7 +116,7 @@ struct GNUNET_TRANSPORT_CommunicatorGenericFCLimits
   uint64_t bytes_window_size;
 
   /**
-   * Cummulative acknowledgement for number of bytes received.
+   * Cumulative acknowledgement for number of bytes received.
    */
   uint64_t bytes_cummulative_ack;
 
diff --git a/src/transport/ieee80211_radiotap.h 
b/src/transport/ieee80211_radiotap.h
index 1a79cf214..9351da9a5 100644
--- a/src/transport/ieee80211_radiotap.h
+++ b/src/transport/ieee80211_radiotap.h
@@ -248,7 +248,7 @@ enum ieee80211_radiotap_type
 #define IEEE80211_RADIOTAP_F_TX_RTS     0x0004  /* used rts/cts handshake */
 
 /* Ugly macro to convert literal channel numbers into their mhz equivalents
- * There are certianly some conditions that will break this (like feeding it 
'30')
+ * There are certainly some conditions that will break this (like feeding it 
'30')
  * but they shouldn't arise since nothing talks on channel 30. */
 #define ieee80211chan2mhz(x) \
   (((x) <= 14) ? \
diff --git a/src/transport/plugin_transport_wlan.h 
b/src/transport/plugin_transport_wlan.h
index 9ba9d2771..d175f9377 100644
--- a/src/transport/plugin_transport_wlan.h
+++ b/src/transport/plugin_transport_wlan.h
@@ -109,7 +109,7 @@ struct GNUNET_TRANSPORT_WLAN_Ieee80211Frame
 {
   /**
    * 802.11 Frame Control field.  A bitmask.  The overall field is a
-   * 16-bit mask of the respecitve fields.  The lowest two bits should
+   * 16-bit mask of the respective fields.  The lowest two bits should
    * be 0, then comes the "type" (2 bits, see IEEE80211_FC0_TYPE_*
    * constants), followed by 4-bit subtype (all zeros for ad-hoc),
    * followed by various flags (to DS, from DS, more frag, retry,
diff --git a/src/transport/transport-testing.h 
b/src/transport/transport-testing.h
index 0f7c51ce5..c548e59c1 100644
--- a/src/transport/transport-testing.h
+++ b/src/transport/transport-testing.h
@@ -181,7 +181,7 @@ struct GNUNET_TRANSPORT_TESTING_ConnectRequest
   struct GNUNET_SCHEDULER_Task *tct;
 
   /**
-   * Handle by which we ask ATS to faciliate the connection.
+   * Handle by which we ask ATS to facilitate the connection.
    */
   struct GNUNET_ATS_ConnectivitySuggestHandle *ats_sh;
 
@@ -348,7 +348,7 @@ GNUNET_TRANSPORT_TESTING_connect_peers (
 /**
  * Cancel the request to connect two peers.  You MUST cancel the
  * request if you stop the peers before the peers connected
- * succesfully.
+ * successfully.
  *
  * @param cc a connect request handle
  */
@@ -902,7 +902,7 @@ GNUNET_TRANSPORT_TESTING_get_test_plugin_name (const char 
*executable,
 
 /**
  * Extracts the filename from an absolute file name and removes the
- * extenstion
+ * extension
  *
  * @param file absolute file name
  * @return the source name
diff --git a/src/transport/transport-testing2.h 
b/src/transport/transport-testing2.h
index db8700df9..e2167ca7e 100644
--- a/src/transport/transport-testing2.h
+++ b/src/transport/transport-testing2.h
@@ -197,7 +197,7 @@ struct GNUNET_TRANSPORT_TESTING_ConnectRequest
   struct GNUNET_SCHEDULER_Task *tct;
 
   /**
-   * Handle by which we ask ATS to faciliate the connection.
+   * Handle by which we ask ATS to facilitate the connection.
    */
   struct GNUNET_ATS_ConnectivitySuggestHandle *ats_sh;
 
@@ -358,7 +358,7 @@ GNUNET_TRANSPORT_TESTING_connect_peers (
 /**
  * Cancel the request to connect two peers.  You MUST cancel the
  * request if you stop the peers before the peers connected
- * succesfully.
+ * successfully.
  *
  * @param cc a connect request handle
  */
@@ -912,7 +912,7 @@ GNUNET_TRANSPORT_TESTING_get_test_plugin_name (const char 
*executable,
 
 /**
  * Extracts the filename from an absolute file name and removes the
- * extenstion
+ * extension
  *
  * @param file absolute file name
  * @return the source name
diff --git a/src/transport/transport.h b/src/transport/transport.h
index dbae4ecfb..8ffc87070 100644
--- a/src/transport/transport.h
+++ b/src/transport/transport.h
@@ -64,7 +64,7 @@
   GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 1)
 
 /**
- * Similiar to GNUNET_TRANSPORT_NotifyDisconnect but in and out quotas are
+ * Similar to GNUNET_TRANSPORT_NotifyDisconnect but in and out quotas are
  * included here. These values are not required outside transport_api
  *
  * @param cls closure
@@ -428,7 +428,7 @@ struct ValidationIterateResponseMessage
 
   /**
    * Until when is the address believed to be valid.
-   * Will be ZERO if the address is not belived to be valid.
+   * Will be ZERO if the address is not believed to be valid.
    */
   struct GNUNET_TIME_AbsoluteNBO valid_until;
 
@@ -452,7 +452,7 @@ struct ValidationMonitorMessage
   struct GNUNET_MessageHeader header;
 
   /**
-   * One shot call or continous replies?
+   * One shot call or continuous replies?
    */
   uint32_t one_shot GNUNET_PACKED;
 
@@ -475,7 +475,7 @@ struct PeerMonitorMessage
   struct GNUNET_MessageHeader header;
 
   /**
-   * One shot call or continous replies?
+   * One shot call or continuous replies?
    */
   uint32_t one_shot GNUNET_PACKED;
 
diff --git a/src/util/benchmark.h b/src/util/benchmark.h
index f4eb32191..e35fa50bd 100644
--- a/src/util/benchmark.h
+++ b/src/util/benchmark.h
@@ -161,7 +161,7 @@ get_benchmark_data (void);
 
 /**
  * Get benchmark data for a URL.  If the URL is too long, it's truncated
- * before looking up the correspoding benchmark data.
+ * before looking up the corresponding benchmark data.
  *
  * Statistics are bucketed by URL and status code.
  *

diff --git a/src/testbed/gnunet-service-testbed_links.c 
b/src/testbed/gnunet-service-testbed_links.c
index fb25d7bcb..dbdeed0d9 100644
--- a/src/testbed/gnunet-service-testbed_links.c
+++ b/src/testbed/gnunet-service-testbed_links.c
@@ -155,7 +155,7 @@ struct NeighbourConnectNotification
   /**
    * The notification callback to call when we are connect to neighbour
    */
-  GST_NeigbourConnectNotifyCallback cb;
+  GST_NeighbourConnectNotifyCallback cb;
 
   /**
    * The closure for the above callback
@@ -925,7 +925,7 @@ trigger_notifications (struct Neighbour *n)
 
 /**
  * Callback to be called when the neighbour connect operation is started.  The
  * connection to the neigbour is opened here and any pending notifications are
  * trigger.
  *
  * @param cls the neighbour
@@ -971,7 +971,7 @@ oprelease_neighbour_conn (void *cls)
 
 
 /**
  * Try to open a connection to the given neigbour.  If the connection is open
  * already, then it is re-used.  If not, the request is queued in the operation
  * queues responsible for bounding the total number of file descriptors.  The
  * actual connection will happen when the operation queue marks the
@@ -983,7 +983,7 @@ oprelease_neighbour_conn (void *cls)
  */
 struct NeighbourConnectNotification *
 GST_neighbour_get_connection (struct Neighbour *n,
-                              GST_NeigbourConnectNotifyCallback cb,
+                              GST_NeighbourConnectNotifyCallback cb,
                               void *cb_cls)
 {
   struct NeighbourConnectNotification *h;
@@ -1179,7 +1179,7 @@ neighbour_connect_cb (void *cls,
 
 
 /**
- * Function to create a neigbour and add it into the neighbour list
+ * Function to create a neighbour and add it into the neighbour list
  *
  * @param host the host of the neighbour
  */
@@ -925,7 +925,7 @@ trigger_notifications (struct Neighbour *n)
 /**
  * Callback to be called when the neighbour connect operation is started.  The
- * connection to the neigbour is opened here and any pending notifications are
+ * connection to the neighbour is opened here and any pending notifications are
  * trigger.
  *
@@ -971,7 +971,7 @@ oprelease_neighbour_conn (void *cls)
 
 /**
- * Try to open a connection to the given neigbour.  If the connection is open
+ * Try to open a connection to the given neighbour.  If the connection is open
  * already, then it is re-used.  If not, the request is queued in the operation
  * queues responsible for bounding the total number of file descriptors.  The
diff --git a/src/testbed/gnunet-service-testbed_links.h 
b/src/testbed/gnunet-service-testbed_links.h
index 021895b1c..74db0bd47 100644
--- a/src/testbed/gnunet-service-testbed_links.h
+++ b/src/testbed/gnunet-service-testbed_links.h
@@ -129,13 +129,13 @@ struct NeighbourConnectNotification;
  * @param controller the controller handle to the neighbour
  */
 typedef void
-(*GST_NeigbourConnectNotifyCallback) (void *cls,
-                                      struct GNUNET_TESTBED_Controller *
-                                      controller);
+(*GST_NeighbourConnectNotifyCallback) (void *cls,
+                                       struct GNUNET_TESTBED_Controller *
+                                       controller);
 
 
 /**
  * Try to open a connection to the given neigbour.  If the connection is open
  * already, then it is re-used.  If not, the request is queued in the operation
  * queues responsible for bounding the total number of file descriptors.  The
  * actual connection will happen when the operation queue marks the
@@ -147,7 +147,7 @@ typedef void
  */
 struct NeighbourConnectNotification *
 GST_neighbour_get_connection (struct Neighbour *n,
-                              GST_NeigbourConnectNotifyCallback cb,
+                              GST_NeighbourConnectNotifyCallback cb,
                               void *cb_cls);
 
 
@@ -172,7 +172,7 @@ GST_neighbour_release_connection (struct Neighbour *n);
 
 
 /**
- * Function to create a neigbour and add it into the neighbour list
+ * Function to create a neighbour and add it into the neighbour list
  *
  * @param host the host of the neighbour
  */
@@ -129,13 +129,13 @@ struct NeighbourConnectNotification;
 
 /**
- * Try to open a connection to the given neigbour.  If the connection is open
+ * Try to open a connection to the given neighbour.  If the connection is open
  * already, then it is re-used.  If not, the request is queued in the operation
  * queues responsible for bounding the total number of file descriptors.  The
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]